==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
var DataGridSummaryResultDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataGridSummaryResultDescriptionMetadata, _super);
    function DataGridSummaryResultDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataGridSummaryResultDescriptionMetadata.b = function (a) {
        if (DataGridSummaryResultDescriptionMetadata.a == null) {
            DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
        }
        if (a.k(DataGridSummaryResultDescriptionMetadata.a)) {
            return;
        }
        a.ab(DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.c = function (a) {
        a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
        a.item("Value", "Unknown");
        a.item("SummaryIndex", "Number:int");
    };
    DataGridSummaryResultDescriptionMetadata.d = function (a) {
        DataGridSummaryResultDescriptionMetadata.b(a);
        a.ad("DataGridSummaryResult", function () { return new DataGridSummaryResultDescription(); });
        a.ac("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.$t = markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
}(Base));
export { DataGridSummaryResultDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
var DataGridSummaryResultDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataGridSummaryResultDescriptionMetadata, _super);
    function DataGridSummaryResultDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataGridSummaryResultDescriptionMetadata.b = function (a) {
        if (DataGridSummaryResultDescriptionMetadata.a == null) {
            DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
        }
        if (a.k(DataGridSummaryResultDescriptionMetadata.a)) {
            return;
        }
        a.ac(DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.c = function (a) {
        a.item("__marshalByValue", "Boolean");
        a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
        a.item("Value", "Unknown");
        a.item("SummaryIndex", "Number:int");
    };
    DataGridSummaryResultDescriptionMetadata.d = function (a) {
        DataGridSummaryResultDescriptionMetadata.b(a);
        a.ae("DataGridSummaryResult", function () { return new DataGridSummaryResultDescription(); });
        a.ad("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
    };
    DataGridSummaryResultDescriptionMetadata.$t = markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
}(Base));
export { DataGridSummaryResultDescriptionMetadata };
